==> gap-packages-4.12.1-2-x86_64.pkg.tar.zst: usr/lib/gap/pkg/agt/CHANGES.md <==
# AGT package for GAP - CHANGES.md

Copyright (C) 2020 by Rhys J. Evans. 

Licensing information can be found in the LICENSE file.

## Version 0.2 (released 02/03/2020)
These changes are mostly in preparation for the release of the AGT package as 
a deposited package in GAP. Most changes were made by or have been suggested by 
[Max Horn](https://www.quendi.de/math) and [Alexander Konovalov](https://alex-konovalov.github.io/year-archive/).

Changes made:

* Migrated source repository to [gap-packages](https://github.com/gap-packages/).
* Changed references to old repository in PackageInfo.g and README.md [Issue #5](https://github.com/gap-packages/agt/issues/5). 
* Deleted unused files [PR #6](https://github.com/gap-packages/agt/pull/6).
* Updated Travis integration [PR #7](https://github.com/gap-packages/agt/pull/7).
* Clarified licensing [Issue #8](https://github.com/gap-packages/agt/issues/8).
* Changed AGT_SRGFilename to follow standard conventions [PR #9](https://github.com/gap-packages/agt/pull/9).
* Removed further unused files and updated .gitignore [Issue #10](https://github.com/gap-packages/agt/issues/10).
* Updated package dependencies [Commit 7ba9db9](https://github.com/gap-packages/agt/commit/7ba9db94f6afa952ad5203ccfdc56c7459605205).
* Removed inner loop in calculations of RegularAdjacencyUpperBound and RegularAdjacencyLowerBound [Commit 74da953](https://github.com/gap-packages/agt/commit/74da95376e99fbf51acd5e2856f80223c2d5a7a0).
 
## Version 0.1 (released 03/02/2020)
First version made publicly available on github.

==> gap-packages-4.15.1-1-x86_64.pkg.tar.zst: usr/lib/gap/pkg/agt/CHANGES.md <==
# AGT package for GAP - CHANGES.md

Copyright (C) 2020 by Rhys J. Evans. 

Licensing information can be found in the LICENSE file.

## Version 0.3.1 (released 31/12/2002)
Fixed tarball symlink [Issue #15](https://github.com/gap-packages/agt/issues/15)

## Version 0.3 (released 22/10/2022)
These changes involved editing old links and contact information. 
Most changes were made or suggested by [Max Horn](https://www.quendi.de/math). 

## Version 0.2 (released 02/03/2020)
These changes are mostly in preparation for the release of the AGT package as 
a deposited package in GAP. Most changes were made by or have been suggested by 
[Max Horn](https://www.quendi.de/math) and [Alexander Konovalov](https://alex-konovalov.github.io/year-archive/).

Changes made:

* Migrated source repository to [gap-packages](https://github.com/gap-packages/).
* Changed references to old repository in PackageInfo.g and README.md [Issue #5](https://github.com/gap-packages/agt/issues/5). 
* Deleted unused files [PR #6](https://github.com/gap-packages/agt/pull/6).
* Updated Travis integration [PR #7](https://github.com/gap-packages/agt/pull/7).
* Clarified licensing [Issue #8](https://github.com/gap-packages/agt/issues/8).
* Changed AGT_SRGFilename to follow standard conventions [PR #9](https://github.com/gap-packages/agt/pull/9).
* Removed further unused files and updated .gitignore [Issue #10](https://github.com/gap-packages/agt/issues/10).
* Updated package dependencies [Commit 7ba9db9](https://github.com/gap-packages/agt/commit/7ba9db94f6afa952ad5203ccfdc56c7459605205).
* Removed inner loop in calculations of RegularAdjacencyUpperBound and RegularAdjacencyLowerBound [Commit 74da953](https://github.com/gap-packages/agt/commit/74da95376e99fbf51acd5e2856f80223c2d5a7a0).
 
## Version 0.1 (released 03/02/2020)
First version made publicly available on github.
